@@ -1,4 +1,4 @@
-use super::{PluginInfo, APIVersion};
+use super::{PluginInfo, APIVersion, Message, SendStatus};
 use crate::types::Account;
 
 #[derive(Debug)]
@@ -7,6 +7,7 @@ pub struct InitializedPlugin {
 
     pub create_account: extern fn() -> Account,
     pub destroy_account: extern fn(acc: Account),
+    pub post_message: extern fn(msg: * const Message) -> SendStatus,
     pub print: extern fn(acc: Account)
 }
 
@@ -16,6 +17,8 @@ impl InitializedPlugin {
             return Err("create_account is not defined".to_string());
         } else if plugin.destroy_account.is_none() {
             return Err("destroy_account is not defined".to_string());
+        } else if plugin.post_message.is_none() {
+            return Err("post_message is not defined".to_string());
         } else if plugin.print.is_none() {
             return Err("print is not defined".to_string());
         }
@@ -24,7 +27,8 @@ impl InitializedPlugin {
             supported_api: plugin.supported_api,
             create_account: plugin.create_account.unwrap(),
             destroy_account: plugin.destroy_account.unwrap(),
+            post_message: plugin.post_message.unwrap(),
             print: plugin.print.unwrap()
         })
     }
-}
\ No newline at end of file
+}
